//=================================================================
//                    PriviledgedControl Class
//=================================================================
// 
//    This class provides a mechanism for class loading for both
// plugins and the database JDBC drivers.
//
//                 << PriviledgedControl.java >>
//
//=================================================================
// Copyright (C) 2016-2024 Dana M. Proctor
// Version 1.3 02/07/2024
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version
// 2 of the License, or (at your option) any later version. This
// program is distributed in the hope that it will be useful, 
// but WITHOUT ANY WARRANTY; without even the implied warranty
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
// the GNU General Public License for more details. You should
// have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
// (http://opensource.org)
//
//=================================================================
// Revision History
// Changes to the code should be documented here and reflected
// in the present version number. Author information should
// also be included with the original copyright author.
//=================================================================
// Version 1.0 07/29/2019 Original PriviledgedControl Class.
//         1.1 08/01/2019 Method run() Added Catch for SecurityException.
//         1.2 09/24/2023 Replacement of URL Creation Directly via String in Constructor
//                        With Instantiation via URI then URI.toURL(). Deprecated in
//                        Order to Force Developers to Use URIs that Specifies Components
//                        of Resource. Method Effected run().
//         1.3 02/07/2024 Constructor Insured Proper Separator, Forward Slash.
//
//-----------------------------------------------------------------
//                 danap@dandymadeproductions.com
//=================================================================

package com.dandymadeproductions.ajqvue.plugin;

import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.net.URLClassLoader;
import java.security.PrivilegedAction;

import com.dandymadeproductions.ajqvue.gui.PluginFrame;

/**
 *    The PriviledgedControl class provides a mechanism for class loading
 * for both plugins and the database JDBC drivers.
 * 
 * @author Dana M. Proctor
 * @version 1.3 02/07/2024
 */

public class PriviledgedControl implements PrivilegedAction<ClassLoader>
{
   // Class Instances
   private String pluginURLString;
   private boolean isPlugin;
   private boolean debug;
   
   //==============================================================
   // PriviledgedControl Constructor
   // 
   // pluginURLString example: file:/home/myClass.jar.
   //==============================================================
   
   public PriviledgedControl(String pluginURLString, boolean isPlugin, boolean debug)
   {
      this.pluginURLString = pluginURLString;
      this.isPlugin = isPlugin;
      this.debug = debug;
   }
   
   @Override
   public ClassLoader run()
   {
      try
      {
         if (debug)
            System.out.println("PriviledgedControl run() pluginURLString: " + pluginURLString);
         
         return new URLClassLoader(new URL[] {(new URI(pluginURLString.replace("\\", "/"))).toURL()},
                                   ClassLoader.getSystemClassLoader());
      }
      catch (URISyntaxException | MalformedURLException | SecurityException e)
      {
         if (debug)
            System.out.println("PrivildegedControl run() " + e);
         
         if (isPlugin)
         {
            Thread removePluginConfigurationModuleThread = new Thread(new Runnable()
            {
               public void run()
               {
                  PluginFrame.removePluginConfigurationModule(pluginURLString);
               }
            }, "PriviledgedControl.removePluginConfigurationModuleThread1");
            removePluginConfigurationModuleThread.start(); 
         }
         
         return null;
      }
   }
}
