-- =============================================================
-- Test table to create the various data types that are
-- defined by the H2 database.
-- =============================================================
-- Dana Proctor 
-- Version 08/26/2013 Original Test Data Type Table.
-- Version 10/20/2023 Updated to Reflect Data Types H2 2.2.222.
--         12/11/2023 Added Comment to integer_array_type.
--         12/25/2023 Removed integer_array_type Field.
--      
-- danap@dandymadeproductions.com
-- =============================================================

DROP TABLE IF EXISTS "h2types";
CREATE TABLE "h2types" (

--  Table id and creation data entries.

    "data_type_id" IDENTITY PRIMARY KEY,

--  Character type fields.

    "char_type" CHAR(30) DEFAULT NULL,
    "varchar_type" VARCHAR(30) DEFAULT NULL,
    "varchar_type_ignorecase" VARCHAR_IGNORECASE(30) DEFAULT NULL,
    "clob_type" CLOB(1M) DEFAULT NULL,
    
--  Blob type fields.
    
    "binary_type" BINARY(1000) DEFAULT NULL,
    "binary_varying_type" BINARY VARYING(100000) DEFAULT NULL,
    "blob_type" BLOB(1M) DEFAULT NULL,

--  Other type fields.

    "object_type" OBJECT(100000),
    "enum_type" ENUM('New', 'Used') NOT NULL DEFAULT 'New',
    "json_type" JSON(10000) DEFAULT NULL,
    "uuid_type" UUID DEFAULT NULL,

--  Numeric fields.

    "boolean_type" BOOLEAN DEFAULT NULL,
    "tinyInt_type" TINYINT DEFAULT NULL,
    "smallInt_type" SMALLINT DEFAULT NULL,
    "int_type" INT DEFAULT NULL,
    "bigInt_type" BIGINT DEFAULT NULL,
    "numeric_type" NUMERIC(16,2) DEFAULT NULL,
    "real_type" REAL DEFAULT NULL,
    "doublePrecision_type" DOUBLE PRECISION DEFAULT NULL,
    "decfloat_type" DECFLOAT(20) DEFAULT NULL,
    
--  Date and time fields.

    "date_type" DATE DEFAULT NULL,
    "time_type" TIME(3) DEFAULT NULL,
    "timeTMZ_type" TIME(9) WITH TIME ZONE,
    "timeStamp_type" TIMESTAMP DEFAULT NULL,
    "timeStampTMZ_type" TIMESTAMP(3) WITH TIME ZONE DEFAULT NULL,
    "interval_type" INTERVAL DAY TO SECOND DEFAULT NULL,
    
--  Geometric fields.

    "geometry_type" GEOMETRY(POINT) DEFAULT NULL
);

--
-- View for h2types
--

-- DROP VIEW IF EXISTS "myView";
CREATE VIEW "myView" AS SELECT * FROM "h2types";


