-- =============================================================
-- Test table to create the various data types as arrays.
-- =============================================================
-- Dana Proctor 
-- Version 12/10/2023 Initial array_types Test Table. Unresolved Format
--                    for object_array Insert.
--         01/02/2024 Changed Table Data Insert Statemente for JAVA_OBJECT
--                    from Default to a CAST. 
--
-- danap@dandymadeproductions.com
-- =============================================================

DROP TABLE IF EXISTS "array_types";
CREATE TABLE "array_types" (

--  Table id and creation data entries.
    "data_type_id" IDENTITY PRIMARY KEY,
    
--  Character type fields.

    "char_array" CHAR(30) ARRAY[10] DEFAULT NULL,
    "varchar_array" VARCHAR(30) ARRAY[10] DEFAULT NULL,
    "varchar_ignorecase_array" VARCHAR_IGNORECASE(30) ARRAY[10] DEFAULT NULL,
    "clob_array" CLOB(10000) ARRAY[10] DEFAULT NULL,
    
--  Blob type fields.
    
    "binary_array" BINARY(1000) ARRAY[10] DEFAULT NULL,
    "binary_varying_array" BINARY VARYING(10000) ARRAY[10] DEFAULT NULL,
    "blob_array" BLOB(10000) ARRAY[10] DEFAULT NULL,

--  Other type fields.

    "object_array" OBJECT(10000) ARRAY[10] DEFAULT NULL,
    "enum_array" ENUM('New', 'Used') ARRAY[10] NOT NULL DEFAULT 'New',
    "json_array" JSON(10000) ARRAY[10] DEFAULT NULL,
    "uuid_array" UUID ARRAY[10] DEFAULT NULL,

--  Numeric fields.

    "boolean_array" BOOLEAN ARRAY[10] DEFAULT NULL,
    "tinyInt_array" TINYINT ARRAY[10] DEFAULT NULL,
    "smallInt_array" SMALLINT ARRAY[10] DEFAULT NULL,
    "int_array" INTEGER ARRAY[10] DEFAULT NULL,
    "bigInt_array" BIGINT ARRAY[10] DEFAULT NULL,
    "numeric_array" NUMERIC(16,2) ARRAY[10] DEFAULT NULL,
    "real_array" REAL ARRAY[10] DEFAULT NULL,
    "doublePrecision_array" DOUBLE PRECISION ARRAY[10] DEFAULT NULL,
    "decfloat_array" DECFLOAT(20) ARRAY[10] DEFAULT NULL,
    
--  Date and time fields.

    "date_array" DATE ARRAY[10] DEFAULT NULL,
    "time_array" TIME(3) ARRAY[10] DEFAULT NULL,
    "timeTMZ_array" TIME(9) WITH TIME ZONE ARRAY[10] DEFAULT NULL,
    "timeStamp_array" TIMESTAMP ARRAY[10] DEFAULT NULL,
    "timeStampTMZ_array" TIMESTAMP(3) WITH TIME ZONE ARRAY[10] DEFAULT NULL,
    "interval_array" INTERVAL DAY TO SECOND ARRAY[10] DEFAULT NULL,
    
--  Geometric fields.

    "geometry_array" GEOMETRY(POINT) ARRAY[10] DEFAULT NULL

);

INSERT INTO "array_types" 
("data_type_id",
 "char_array","varchar_array","varchar_ignorecase_array","clob_array",
 "binary_array","binary_varying_array","blob_array",
 "object_array","enum_array","json_array","uuid_array",
 "boolean_array","tinyInt_array","smallInt_array","int_array","bigInt_array",
 "numeric_array","real_array","doublePrecision_array","decfloat_array",
 "date_array","time_array","timeTMZ_array","timeStamp_array",
 "timeStampTMZ_array",
 "interval_array",
 "geometry_array") 
VALUES 
    (DEFAULT,
-- char_array
  ARRAY['abc','cba'],
-- varchar_array
  ARRAY['abc','cba'],
-- varchar_ignorecase_array
  ARRAY['abc','cba'],
-- clob_array
  ARRAY['clob','clob2'],
-- binary_array
  ARRAY[x'225b312c2727325d22'],
-- binary_varying_array
  ARRAY[x'225b312c2727325d22'],
-- blob_array
  ARRAY[x'225b312c2727325d22'],
-- object_array
--  default,
  ARRAY [CAST(X'225b312c2727325d22' AS OBJECT(10000))],
--  ARRAY[x'225b312c2727325d22'],
-- enum_array
  ARRAY['New','Used'],
-- json_array
  ARRAY[JSON X'225b312c2727325d22'],
-- uuid_array
  ARRAY['6a3d0c76-857f-4dff-9d80-6b5315389c8b'],
-- boolean_array
  ARRAY[1,0],
-- tinyInt_array
  ARRAY[1,2,4,7],
-- smallInt_array
  ARRAY[1,2,4,7],
-- int_array
  ARRAY[1,2,4,7],
-- bigInt_array
  ARRAY[3,4],
-- numeric_array
  ARRAY[1.25,2.45],
-- real_array
  ARRAY[1.2,2.4],
-- doublePrecision_array
  ARRAY[1.2,2.4],
-- decfloat_array
  ARRAY[1.2,2.4],
-- date_array
  ARRAY['2008-02-25','2023-12-12'],
-- time_array
  ARRAY['12:00:00'],
-- timeTMZ_array
  ARRAY['12:00:00'],
-- timeStamp_array
  ARRAY['2008-02-25 12:00:00', NOW()],
-- timeStampTMZ_array
  ARRAY['2023-12-02 12:37:01', NOW()],
-- interval_array
  ARRAY[INTERVAL '10 11:12:13.123' DAY TO SECOND],
-- geometry_array
  ARRAY['POINT (3 4)']);

    




