-- ============================================================
--   Test table to create tables with all data type fields
-- support by H2 to test the loading of TableTabPanel
-- summary table, (JTable), TableViewForm, and TableEntryForm. 
-- =============================================================
-- Version 11/13/2023 Original Load Test SQL Configuration for
--                    Tables of H2 Data Types.
--         12/13/2023 Table geometry_types Changed Point Real Values
--                    to Integers. Seems Geometry Data Types Can Only
--                    be Integers. Changed Insert for integer_array_types
--                    to Correct Format.
--         04/03/2024 Insert Statement for jason_types Used JSON to Process
--                    as Such in Database Parser. 
--      
-- danap@dandymadeproductions.com
-- =============================================================

-- #############################################################
--
-- DROP TABLE SECTION
--
-- #############################################################

-- character types

DROP TABLE IF EXISTS "char_types";
DROP TABLE IF EXISTS "varchar_types";
DROP TABLE IF EXISTS "varchar_types_ignorecase";

-- text types

DROP TABLE IF EXISTS "clob_types";

-- blob types

DROP TABLE IF EXISTS "binary_types";
DROP TABLE IF EXISTS "binary_varying_types";
DROP TABLE IF EXISTS "blob_types";

-- enumeration and other types

DROP TABLE IF EXISTS "object_types";
DROP TABLE IF EXISTS "enum_types";
DROP TABLE IF EXISTS "json_types";
DROP TABLE IF EXISTS "uuid_types";

-- boolean types

DROP TABLE IF EXISTS "boolean_types";

-- integer types

DROP TABLE IF EXISTS "tinyInt_types";
DROP TABLE IF EXISTS "smallInt_types";
DROP TABLE IF EXISTS "int_types";
DROP TABLE IF EXISTS "bigInt_types";

-- float types

DROP TABLE IF EXISTS "real_types";
DROP TABLE IF EXISTS "doubleprecision_types";
DROP TABLE IF EXISTS "numeric_types";
DROP TABLE IF EXISTS "decfloat_types";

-- date types

DROP TABLE IF EXISTS "date_types";
DROP TABLE IF EXISTS "time_types";
DROP TABLE IF EXISTS "timeTMZ_types";
DROP TABLE IF EXISTS "timeStamp_types";
DROP TABLE IF EXISTS "timeStampTMZ_types";
DROP TABLE IF EXISTS "interval_types";

DROP TABLE IF EXISTS "geometry_types";
DROP TABLE IF EXISTS "integer_array_types";


-- #############################################################
-- 
-- CREATE TABLE SECTION
--
-- #############################################################

CREATE TABLE "char_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    char_type CHAR(30) DEFAULT NULL
);


CREATE TABLE "varchar_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    varchar_type VARCHAR(30) DEFAULT NULL
);

CREATE TABLE "varchar_types_ignorecase" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    varchar_type_ignorecase VARCHAR_IGNORECASE(30) DEFAULT NULL
);

CREATE TABLE "clob_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    clob_type CLOB DEFAULT NULL
);

CREATE TABLE "binary_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    binary_type BINARY(1000) DEFAULT NULL
);

CREATE TABLE "binary_varying_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    binary_varying_type BINARY VARYING(10000) DEFAULT NULL
);

CREATE TABLE "blob_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    blob_type BLOB DEFAULT NULL
);

CREATE TABLE "object_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    object_type OBJECT(100000) DEFAULT NULL
);

CREATE TABLE "enum_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    enum_type ENUM('New', 'Used') NOT NULL DEFAULT 'New'
);

CREATE TABLE "json_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    json_type JSON DEFAULT NULL
);

CREATE TABLE "uuid_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    uuid_type UUID DEFAULT NULL
);

CREATE TABLE "boolean_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    boolean_type BOOLEAN DEFAULT NULL
);

CREATE TABLE "tinyInt_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    tinyInt_type TINYINT DEFAULT NULL
);

CREATE TABLE "smallInt_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    smallInt_type SMALLINT DEFAULT NULL
);

CREATE TABLE "int_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    int_type INT DEFAULT NULL
);

CREATE TABLE "bigInt_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    bigInt_type BIGINT DEFAULT NULL
);

CREATE TABLE "real_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    real_type REAL DEFAULT NULL
);

CREATE TABLE "doubleprecision_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    doubleprecision_type DOUBLE PRECISION DEFAULT NULL
);

CREATE TABLE "numeric_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    numeric_type DECIMAL(16,2) DEFAULT NULL
);

CREATE TABLE "decfloat_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    decfloat_type DECFLOAT(20) DEFAULT NULL
);

CREATE TABLE "date_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    date_type DATE DEFAULT NULL
);

CREATE TABLE "time_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    time_type TIME DEFAULT NULL
);

CREATE TABLE "timeTMZ_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    timeTMZ_type TIME WITH TIME ZONE DEFAULT NULL
);

CREATE TABLE "timeStamp_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    timeStamp_type TIMESTAMP DEFAULT NULL
);

CREATE TABLE "timeStampTMZ_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    timeStampTMZ_type TIMESTAMP WITH TIME ZONE DEFAULT NULL
);

CREATE TABLE "interval_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    interval_type INTERVAL DAY TO SECOND DEFAULT NULL
);

CREATE TABLE "geometry_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    geometry_type GEOMETRY(POINT) DEFAULT NULL
);

CREATE TABLE "integer_array_types" (

--  Table id and creation data entries.
    data_type_id IDENTITY PRIMARY KEY,
    integer_array_type INTEGER ARRAY[10] DEFAULT NULL
);

-- #############################################################
--
-- INSERT INTO TABLE SECTION
--
-- #############################################################

INSERT INTO "char_types"
    (char_type)
VALUES
    ('a'),
    ('ccaaaaaaaaaaaaaaaaaaaaaaaaaaa');

INSERT INTO "varchar_types"
    (varchar_type)
VALUES
    ('a'),
    ('ccaaaaaaaaaaaaaaaaaaaaaaaaaaa');
    
INSERT INTO "varchar_types_ignorecase"
    (varchar_type_ignorecase)
VALUES
    ('A'),
    ('Ccaaaaaaaaaaaaaaaaaaaaaaaaaaa');

INSERT INTO "clob_types"
    (clob_type)
VALUES
    (',,!!!\\\\\\##');

INSERT INTO "binary_types"
    (binary_type)
VALUES
    (',,!!!\\\\\\##');

INSERT INTO "binary_varying_types"
    (binary_varying_type)
VALUES
    (',,!!!\\\\\\##');

INSERT INTO "blob_types"
    (blob_type)
VALUES
    (',,!!!\\\\\\##');

INSERT INTO "object_types"
    (object_type)
VALUES
    (x'2c2c2121215c5c5c5c5c5c23230a');

INSERT INTO "enum_types"
    (enum_type)
VALUES
    ('New'),
    ('Used');

INSERT INTO "json_types"
    (json_type)
VALUES
    (JSON '{"Malaysia":1498243856000}');

INSERT INTO "uuid_types"
    (uuid_type)
VALUES
    ('A0EEBC99-9C0B-4EF8-BB6D-6BB9BD380A11');

INSERT INTO "boolean_types"
    (boolean_type)
VALUES
    ('TRUE'),
    ('FALSE');
    
INSERT INTO "tinyInt_types"
    (tinyint_type)
VALUES
    (-128),
    (127);

INSERT INTO "smallInt_types"
    (smallint_type)
VALUES
    (-32768),
    (32767);

INSERT INTO "int_types"
    (int_type)
VALUES
    (-2147483648),
    (2147483647);

INSERT INTO "bigInt_types"
    (bigInt_type)
VALUES
    (-9223372036854775808),
    (9223372036854775807);

INSERT INTO "real_types"
    (real_type)
VALUES
    (3.000001),
    (-3.000001);

INSERT INTO "doubleprecision_types"
    (doubleprecision_type)
VALUES
    (3.000000000000001),
    (-3.000000000000001);

INSERT INTO "numeric_types"
    (numeric_type)
VALUES
    (-100.99),
    (100.99);
    
INSERT INTO "decfloat_types"
    (decfloat_type)
VALUES
    (-100.99),
    (100.99);

INSERT INTO "date_types"
    (date_type)
VALUES
    ('1000-01-01'),
    ('9999-12-31');

INSERT INTO "time_types"
    (time_type)
VALUES
    ('00:00:00'),
    ('23:59:59');
    
INSERT INTO "timeTMZ_types"
    (timeTMZ_type)
VALUES
    ('00:00:00-06'),
    ('23:59:59-06');

INSERT INTO "timeStamp_types"
    (timeStamp_type)
VALUES
    ('1000-01-01 00:00:00.449'),
    ('9999-12-31 12:59:59.449');
    
INSERT INTO "timeStampTMZ_types"
    (timeStampTMZ_type)
VALUES
    ('1000-01-01 00:00:00.449-06'),
    ('9999-12-31 12:59:59.449-06');

INSERT INTO "interval_types"
    (interval_type)
VALUES
    ('10 11:12:13.123');

INSERT INTO "geometry_types"
    (geometry_type)
VALUES
    ('POINT(2 4)');

INSERT INTO "integer_array_types"
    (integer_array_type)
VALUES
    (ARRAY[1,2,3]);
