-- ============================================================
--   Test table to create tables with all data type fields
-- support by PostgreSQL to test the loading of summary table
-- (JTable), TableViewForm, and TableEntryForm. 
-- =============================================================
-- Version 10/29/2007 Original Load Test SQL configuration for
--                    Tables of PostgreSQL data types. NOT TESTED!
--         11/08/2007 Removed Auto-Increment and Replaced INT
--                    ids to be SERIAL. Also Corrected Seperate
--                    Statements for CREATE TABLE Statements.
--                    Tested Import, Functional All, But Commented
--                    Areas, Ex. Geometric Tables.
--         11/19/2007 Modifed All Commented Areas to Be Now Included.
--                    Essentially All Geometric Types and Interval.
--                    Tested Loads Properly.
--         12/14/2007 Cleaned Up Some.
--         02/24/2007 Added Table array_types.
--         02/25/2007 Removed Table array_types, and Moved to
--                    Separate File, postgresqlTypes_array.sql
--         07/21/2010 Updated Contact, Email, Address.
--         07/20/2020 Added Tables smallserial_types and macaddr8_types.
--                    Modified time_types and timetz_types to Include
--                    Precious (3) for Time Field.
--         07/28/2020 Added Table money_types. Modified timeStamp_types
--                    and timeStamptz_types to Include Precision (3)
--                    for Timestamp Field.
--         09/15/2020 Added Table uuid_types. Corrected Create Statement
--                    for smallserial_types small_type Field to smallserial_type.
--         09/18/2020 Added Table int8range_types.
--         10/27/2020 Modified Time & Timestamp Types to Have Default Precision.
--         03/12/2024 Added Tables json_types, jsonb_types, and xml_types.
--                    Uncommented line_types. Minor Formatting Changes.
--
-- danap@dandymadeproductions.com
-- =============================================================

-- #############################################################
--
-- DROP TABLE SECTION
--
-- #############################################################

--  Numeric fields.

	DROP TABLE IF EXISTS smallInt_types;
	DROP TABLE IF EXISTS integer_types;
	DROP TABLE IF EXISTS bigInt_types;
	DROP TABLE IF EXISTS decimal_types;
	DROP TABLE IF EXISTS numeric_types;
	DROP TABLE IF EXISTS money_types;
	DROP TABLE IF EXISTS real_types;
	DROP TABLE IF EXISTS doublePrecision_types;
	DROP TABLE IF EXISTS smallserial_types;
	DROP TABLE IF EXISTS serial_types;
	DROP TABLE IF EXISTS bigSerial_types;
	
--  Character fields.	
	
	DROP TABLE IF EXISTS varchar_types;
	DROP TABLE IF EXISTS char_types;
	DROP TABLE IF EXISTS text_types;
	
--  Binary fields.
	
    DROP TABLE IF EXISTS bytea_types;

--  Other types

    DROP TABLE IF EXISTS json_types;
    DROP TABLE IF EXISTS jsonb_types;
    DROP TABLE IF EXISTS xml_types;
	
--  Date and time fields.

	DROP TABLE IF EXISTS date_types;
	DROP TABLE IF EXISTS time_types;
	DROP TABLE IF EXISTS timeTZ_types;
	DROP TABLE IF EXISTS timeStamp_types;
	DROP TABLE IF EXISTS timeStampTZ_types;
	DROP TABLE IF EXISTS interval_types;

--  Boolean field.

	DROP TABLE IF EXISTS boolean_types;

--  Geometric fields.
	
	DROP TABLE IF EXISTS point_types;
	DROP TABLE IF EXISTS line_types;
	DROP TABLE IF EXISTS lineSegment_types;
	DROP TABLE IF EXISTS box_types;
	DROP TABLE IF EXISTS path_types;
	DROP TABLE IF EXISTS polygon_types;
	DROP TABLE IF EXISTS circle_types;
	
--  Network address fields.
 
 	DROP TABLE IF EXISTS cidr_types;
 	DROP TABLE IF EXISTS inet_types;
 	DROP TABLE IF EXISTS macaddr_types;
 	DROP TABLE IF EXISTS macaddr8_types;
	
--  Bit string fields.

	DROP TABLE IF EXISTS bit2_types;
	DROP TABLE IF EXISTS bitVarying5_types;
	
--   Special fields.

	DROP TABLE IF EXISTS uuid_types;
    DROP TABLE IF EXISTS int8range_types;
	
-- #############################################################
-- 
-- CREATE TABLE SECTION
--
-- #############################################################

CREATE TABLE smallInt_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    smallInt_type smallint DEFAULT NULL
);

CREATE TABLE integer_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    int_type integer DEFAULT NULL
);

CREATE TABLE bigInt_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    bigInt_type bigint DEFAULT NULL
);

CREATE TABLE decimal_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    decimal_type decimal(16,2) DEFAULT NULL 
);

CREATE TABLE numeric_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    numeric_type numeric DEFAULT NULL 
);

CREATE TABLE money_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    money_type money DEFAULT NULL 
);

CREATE TABLE real_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    real_type real DEFAULT NULL
);

CREATE TABLE doublePrecision_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    doublePrecision_type double precision DEFAULT NULL
);

CREATE TABLE smallserial_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    smallserial_type smallserial
);

CREATE TABLE serial_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    serial_type serial
);

CREATE TABLE bigSerial_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    bigSerial_type bigserial
);

CREATE TABLE varchar_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    varchar_type varchar(30) DEFAULT NULL
);

CREATE TABLE char_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    char_type char(30) DEFAULT NULL
);

CREATE TABLE text_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    text_type text DEFAULT NULL
);

CREATE TABLE bytea_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    bytea_type bytea DEFAULT NULL
);

CREATE TABLE json_types (
	data_type_id serial NOT NULL,
	json_type json DEFAULT NULL,
	PRIMARY KEY  (data_type_id)
);

CREATE TABLE jsonb_types (
	data_type_id serial NOT NULL,
	jsonb_type jsonb DEFAULT NULL,
	PRIMARY KEY  (data_type_id)
);

CREATE TABLE xml_types (
	data_type_id serial NOT NULL,
	xml_type xml DEFAULT NULL,
	PRIMARY KEY  (data_type_id)
 );

CREATE TABLE date_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    date_type date DEFAULT NULL
);

CREATE TABLE time_types (

--  Table id and creation data entries.
     data_type_id SERIAL NOT NULL PRIMARY KEY,
     time_type time DEFAULT NULL
);

CREATE TABLE timeTZ_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    timeTZ_type timetz DEFAULT NULL
);

CREATE TABLE timeStamp_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    timestamp_type timestamp DEFAULT NULL
);

CREATE TABLE timeStampTZ_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    timestampTZ_type timestamptz DEFAULT NULL
);

CREATE TABLE interval_types (

--  Table id and creation data entries.
	data_type_id SERIAL NOT NULL PRIMARY KEY,
    interval_type interval DEFAULT NULL
);

CREATE TABLE boolean_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    boolean_type boolean DEFAULT NULL
);

CREATE TABLE point_types (

--  Table id and creation data entries.
	data_type_id SERIAL NOT NULL PRIMARY KEY,
	point_type point DEFAULT NULL
);

CREATE TABLE line_types (

--  Table id and creation data entries.
	data_type_id SERIAL NOT NULL PRIMARY KEY,
	line_type line DEFAULT NULL
);

CREATE TABLE lineSegment_types (

--  Table id and creation data entries.
	data_type_id SERIAL NOT NULL PRIMARY KEY,
	lineSegment_type lseg DEFAULT NULL
);

CREATE TABLE box_types (

--  Table id and creation data entries.
	data_type_id SERIAL NOT NULL PRIMARY KEY,
	box_type box DEFAULT NULL
);

CREATE TABLE path_types (

--  Table id and creation data entries.
	data_type_id SERIAL NOT NULL PRIMARY KEY,
	path_type path DEFAULT NULL
);

CREATE TABLE polygon_types (

--  Table id and creation data entries.
	data_type_id SERIAL NOT NULL PRIMARY KEY,
	polygon_type polygon DEFAULT NULL
);

CREATE TABLE circle_types (

--  Table id and creation data entries.
	data_type_id SERIAL NOT NULL PRIMARY KEY,
	circle_type circle DEFAULT NULL
);

CREATE TABLE cidr_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    cidr_type cidr DEFAULT NULL
);

CREATE TABLE inet_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    inet_type inet DEFAULT NULL
);

CREATE TABLE macaddr_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    macaddr_type macaddr DEFAULT NULL
);

CREATE TABLE macaddr8_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    macaddr8_type macaddr8 DEFAULT NULL
);

CREATE TABLE bit2_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    bit_type bit(2) DEFAULT NULL
);

CREATE TABLE bitVarying5_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    bitVarying_type bit varying(5) DEFAULT NULL
);

CREATE TABLE uuid_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    uuid_type uuid DEFAULT NULL
);

CREATE TABLE int8range_types (

--  Table id and creation data entries.
    data_type_id SERIAL NOT NULL PRIMARY KEY,
    int8range_type int8range DEFAULT NULL
);

-- #############################################################
--
-- INSERT INTO TABLE SECTION
--
-- #############################################################
	
INSERT INTO smallInt_types
    (smallInt_type)
VALUES
    (32767),
    (-32768);

INSERT INTO integer_types
    (int_type)
VALUES
    (2147483647),
    (-2147483648);

INSERT INTO bigInt_types
    (bigInt_type)
VALUES
    (9223372036854775807),
    (-9223372036854775808);

INSERT INTO decimal_types
    (decimal_type)
VALUES
    (100);

INSERT INTO numeric_types
    (numeric_type)
VALUES
    (100);
    
INSERT INTO money_types
    (money_type)
VALUES
    (92233720368547758.07),
    (-92233720368547758.08);

INSERT INTO real_types
    (real_type)
VALUES
    (3.000001),
    (-3.000001);

INSERT INTO doublePrecision_types
    (doublePrecision_type)
VALUES
    (3.000000000000001),
    (-3.000000000000001);
    
INSERT INTO smallserial_types
    (smallserial_type)
VALUES
    (1),
    (32767);

INSERT INTO serial_types
    (serial_type)
VALUES
    (1),
    (2147483647);

INSERT INTO bigSerial_types
    (bigSerial_type)
VALUES
    (1),
    (9223372036854775807);

INSERT INTO varchar_types
    (varchar_type)
VALUES
 	('a'),
    ('aaaaaaaaaabbbbbbbbbbcccccccccc');

INSERT INTO char_types
    (char_type)
VALUES
    ('a'),
    ('aaaaaaaaaabbbbbbbbbbcccccccccc');

INSERT INTO text_types
    (text_type)
VALUES
    ('text');
    
INSERT INTO bytea_types
    (bytea_type)
VALUES
    (',,!!!##');

INSERT INTO "json_types"
    (json_type)
VALUES
    ('{"Malaysia":1498243856000}');

INSERT INTO "jsonb_types"
    (jsonb_type)
VALUES
    ('{"Malaysia":1498243856000}'::jsonb);

INSERT INTO "xml_types"
    (xml_type)
VALUES
    ('<foo>bar</foo>');

INSERT INTO date_types
    (date_type)
VALUES
    ('01/01/4713 BC'),
    ('01/01/5874897 AD');

INSERT INTO time_types
    (time_type)
VALUES
    ('00:00:00.025'),
    ('23:00:00');

INSERT INTO timeTZ_types
    (timeTZ_type)
VALUES
    ('00:00:00.025'),
    ('23:00:00');

INSERT INTO timeStamp_types
    (timeStamp_type)
VALUES
    (NOW());

INSERT INTO timeStampTZ_types
    (timeStampTZ_type)
VALUES
    (NOW());

INSERT INTO interval_types
    (interval_type)
VALUES
   ('178000000'),
   ('-178000000');
    
INSERT INTO boolean_types
    (boolean_type)
VALUES
    (TRUE),
    (FALSE);

INSERT INTO point_types
    (point_type)
VALUES
    ('0,0');

INSERT INTO line_types
    (line_type)
VALUES
   ('(0,0),(10,10)');

INSERT INTO lineSegment_types
    (lineSegment_type)
VALUES
    ('(0,0),(10,10)');

INSERT INTO box_types
   (box_type)
VALUES
   ('(0,0),(10,10)');

INSERT INTO path_types
    (path_type)
VALUES
    ('(0,0),(10,10)');

INSERT INTO polygon_types
    (polygon_type)
VALUES
    ('(0,0),(10,10)');

INSERT INTO circle_types
   (circle_type)
VALUES
    ('<(0,0),10>');

INSERT INTO cidr_types
    (cidr_type)
VALUES
    ('10.1.2.3/32');

INSERT INTO inet_types
    (inet_type)
VALUES
    ('10.1.2.0');

INSERT INTO macaddr_types
    (macaddr_type)
VALUES
    ('08:00:2b:00:01:02');
    
INSERT INTO macaddr8_types
    (macaddr8_type)
VALUES
    ('08:00:2b:01:02:03:04:05');

INSERT INTO bit2_types
    (bit_type)
VALUES
    (B'01');
    
INSERT INTO bitVarying5_types
    (bitVarying_type)
VALUES
    (B'01010');

INSERT INTO uuid_types
    (uuid_type)
VALUES
    ('A0EEBC99-9C0B-4EF8-BB6D-6BB9BD380A11');

INSERT INTO int8range_types
    (int8range_type)
VALUES
    ('[-4,8)'),('[0,20)');
